# Copyright 2020, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V9::Enums::LeadFormCallToActionTypeEnum;

use strict;
use warnings;

use Const::Exporter enums => [
  UNSPECIFIED  => "UNSPECIFIED",
  UNKNOWN      => "UNKNOWN",
  LEARN_MORE   => "LEARN_MORE",
  GET_QUOTE    => "GET_QUOTE",
  APPLY_NOW    => "APPLY_NOW",
  SIGN_UP      => "SIGN_UP",
  CONTACT_US   => "CONTACT_US",
  SUBSCRIBE    => "SUBSCRIBE",
  DOWNLOAD     => "DOWNLOAD",
  BOOK_NOW     => "BOOK_NOW",
  GET_OFFER    => "GET_OFFER",
  REGISTER     => "REGISTER",
  GET_INFO     => "GET_INFO",
  REQUEST_DEMO => "REQUEST_DEMO",
  JOIN_NOW     => "JOIN_NOW",
  GET_STARTED  => "GET_STARTED"
];

1;
